@@ -8,7 +8,7 @@ import lazy_loader as lazy
 __getattr__, __dir__, __all__ = lazy.attach(
     __name__,
 
-    submodules=['armfiles', 'csvfiles', 'icartt', 'mpl', 'noaagml', 'noaapsl', 'pysp2'],
+    submodules=['armfiles', 'csvfiles', 'icartt', 'mpl', 'neon', 'noaagml', 'noaapsl', 'pysp2'],
     submod_attrs={
         'armfiles': [
             'WriteDataset',
@@ -21,6 +21,7 @@ __getattr__, __dir__, __all__ = lazy.attach(
         'csvfiles': ['read_csv'],
         'icartt': ['read_icartt'],
         'mpl': ['proc_sigma_mplv5_read', 'read_sigma_mplv5'],
+        'neon': ['read_neon_csv'],
         'noaagml': [
             'read_gml',
             'read_gml_co2',
