@@ -3,6 +3,7 @@ Module containing utilities for the data.
 
 """
 
+import importlib
 import warnings
 
 import metpy
@@ -11,10 +12,10 @@ import pint
 import scipy.stats as stats
 import xarray as xr
 
-try:
-    import pyart
+spec = importlib.util.find_spec('pyart')
+if spec is not None:
     PYART_AVAILABLE = True
-except ImportError:
+else:
     PYART_AVAILABLE = False
 
 
@@ -585,6 +586,8 @@ def create_pyart_obj(
         raise ImportError(
             'Py-ART needs to be installed on your system to convert to ' 'Py-ART Object.'
         )
+    else:
+        import pyart
     # Get list of variables if none provided
     if variables is None:
         variables = list(obj.keys())
